#include <bits/stdc++.h>

using namespace std;

#define MAXN 1000
#define MAXA (MAXN*(MAXN-1)/2)

/*
    We know that R[0] = 0. This implies that R[N-1] = max(A).

    The next max value must be the difference with one of the two extreme points, and so on, and so on. The problem is that we don't know which one, and therefore we have to implement a backtracking algorithm.
    
    Note that a backtracking algorithm that works only from one side would be too slow for the last subtask (hence, it would get only 70 points).
*/


int N;
int A[MAXA], R[MAXN];

unordered_set<int> used_R;      // each R[i] must be unique

// let's take track of the still available A's; plus, we have to access the max value
multiset<int, greater<int>> available_A;

inline void add(int x) { available_A.insert(x); }
inline bool remove(int x) {
    auto it = available_A.find(x);
    if(it == available_A.end()) return false;
    available_A.erase(it);
    return true;
}

bool reconstruct(int from, int to) {
    if(from > to) return true;
    
    // select next largest value among those available
    int next = *available_A.begin();
    
    // try to work on the left
    R[from] = R[N-1] - next;
    //cout << "  try " << R[from] << endl;
    if(used_R.insert(R[from]).second) {
        // check if the new element is compatible with the previous
        int i = 0, j = to + 1;
        for(; i < from; i++) if(!remove(R[from] - R[i])) goto skip_left_1;
        for(; j < N; j++) if(!remove(R[j] - R[from])) goto skip_left_2;
        
        // solve the subproblem
        if(reconstruct(from + 1, to)) return true;
        
        // backtrack : begin
        skip_left_2:
        while(--j > to) add(R[j] - R[from]);
        
        skip_left_1:
        while(--i >= 0) add(R[from] - R[i]);

        used_R.erase(R[from]);
        // backtrack : end
    }

    // try to work on the right
    R[to] = next;
    //cout << "  try " << R[to] << endl;
    if(from != to && used_R.insert(R[to]).second) {
        // check if the new element is compatible with the previous
        int i = 0, j = to + 1;
        for(; i < from; i++) if(!remove(R[to] - R[i])) goto skip_right_1;
        for(; j < N; j++) if(!remove(R[j] - R[to])) goto skip_right_2;
        
        // solve the subproblem
        if(reconstruct(from, to - 1)) return true;
        
        // backtrack : begin
        skip_right_2:
        while(--j > to) add(R[j] - R[to]);
        
        skip_right_1:
        while(--i >= 0) add(R[to] - R[i]);

        used_R.erase(R[to]);
        // backtrack : end
    }
    
    return false;
}

int main() {
    FILE *fr, *fw;
    int i;

    fr = fopen("input.txt", "r");
    fw = fopen("output.txt", "w");
    assert(1 == fscanf(fr, "%d", &N));
    int M = N*(N-1)/2;
    for(i=0; i<M; i++)
        assert(1 == fscanf(fr, "%d", &A[i]));

    // init the multiset
    available_A.insert(A, A + M);
    
    // init the extreme points
    R[0] = 0;
    used_R.insert(0);
    R[N-1] = *available_A.begin();
    available_A.erase(available_A.begin());
    used_R.insert(R[N-1]);
    
    // start the search
    reconstruct(1, N-2);

    for(i=0; i<N; i++)
        fprintf(fw, "%d ", R[i]);
    fprintf(fw, "\n");
    fclose(fr);
    fclose(fw);
    return 0;
}
